import { ArticlePageProps, NonArticlePageProps } from './templates/shared';
export interface UbwConfigs {
    blogName: string;
    blogUrl: string;
    blogDir: string;
    publicationDir: string;
    cssUrls: string[];
    jsUrls: string[];
    language: string;
    timeZone: string;
    ogp: boolean;
    defaultOgpImageUrl: string;
    additionalTopPageLinks: {
        linkText: string;
        href: string;
    }[];
    generateArticleHeadNodes: (articlesProps: ArticlePageProps) => HastscriptAst[];
    generateNonArticleHeadNodes: (nonArticlePageProps: NonArticlePageProps) => HastscriptAst[];
    renderArticle: (props: ArticlePageProps) => string;
    nonArticles: {
        nonArticlePageId: string;
        path: string;
        pathIsNormalizedToSlash: boolean;
        useLayout: boolean;
        render: (props: NonArticlePageProps) => string;
    }[];
}
export interface ActualUbwConfigs extends Partial<UbwConfigs> {
}
export declare function createDefaultUbwConfigs(): UbwConfigs;
export declare function createInitialUbwConfigs(): ActualUbwConfigs;
export declare function fillWithDefaultUbwConfigs(configs: ActualUbwConfigs): UbwConfigs;
export declare function extractOgpDescription(node: RemarkAstNode): string;
/**
 * Generate an unified's transformer that empty a href of <h1>'s autolink
 */
export declare function generateH1AutolinkHrefReplacementTransformer(autolinkMarkerAttributeName: string): (tree: HastscriptAst) => void;
interface ArticleFrontMatters {
    lastUpdatedAt: string;
    publicId: string;
}
export declare function createInitialArticleFrontMatters(publicId: ArticleFrontMatters['publicId'], lastUpdatedAt: ArticleFrontMatters['lastUpdatedAt']): {
    publicId: string;
    lastUpdatedAt: string;
};
export interface ArticlePage {
    articleId: string;
    publicId: string;
    inputFilePath: string;
    outputFilePath: string;
    rootRelativePath: string;
    permalink: string;
    ogpImageUrl: string;
    ogpDescription: string;
    html: string;
    markdown: string;
    pageTitle: string;
    lastUpdatedAt: Date;
}
export interface NonArticlePage {
    nonArticlePageId: string;
    render: (props: NonArticlePageProps) => string;
    rootRelativePath: string;
    permalink: string;
    outputFilePath: string;
    useLayout: boolean;
    html: string;
}
export declare function createArticlePage(): ArticlePage;
export declare function initializeArticlePages(blogRoot: string, configs: UbwConfigs, articleFileNames: string[]): ArticlePage[];
export declare function getNextAutomaticArticleId(articlePages: ArticlePage[], dateString: string): string;
export declare function preprocessArticlePages(blogRoot: string, configs: UbwConfigs, articlePages: ArticlePage[]): ArticlePage[];
export declare function generateArticlePages(blogRoot: string, configs: UbwConfigs, articlePages: ArticlePage[], nonArticlePages: NonArticlePage[]): ArticlePage[];
export declare function initializeNonArticlePages(blogRoot: string, configs: UbwConfigs): NonArticlePage[];
export declare function preprocessNonArticlePages(blogRoot: string, configs: UbwConfigs, nonArticlePages: NonArticlePage[]): NonArticlePage[];
export declare function generateNonArticlePages(blogRoot: string, configs: UbwConfigs, articlePages: ArticlePage[], nonArticlePages: NonArticlePage[]): NonArticlePage[];
export {};
