"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
/*
 * This file MUST NOT depend on any file in the project.
 */
var date_fns_timezone_1 = require("date-fns-timezone");
var path = require("path");
var url = require("url");
var unistUtilVisit = require('unist-util-visit');
var RELATIVE_SOURCE_DIR_PATH = 'blog-source';
exports.RELATIVE_ARTICLES_DIR_PATH = 'articles';
exports.RELATIVE_EXTERNAL_RESOURCES_DIR_PATH = 'external-resources';
var RELATIVE_EXTERNAL_RESOURCES_DIRECT_PLACEMENT_DIR_PATH = '_direct';
exports.PROJECT_ROOT = path.join(__dirname, '..');
var PRESETS_ROOT = path.join(exports.PROJECT_ROOT, 'presets');
exports.PRESETS_EXTERNAL_RESOURCES_ROOT = path.join(PRESETS_ROOT, exports.RELATIVE_EXTERNAL_RESOURCES_DIR_PATH);
exports.CONFIG_FILE_NAME = 'ubw-configs.js';
function toNormalizedAbsolutePath(pathInput, baseAbsolutePath) {
    var absolutePath = path.isAbsolute(pathInput) ? pathInput : path.join(baseAbsolutePath, pathInput);
    return path.normalize(absolutePath);
}
exports.toNormalizedAbsolutePath = toNormalizedAbsolutePath;
function classifyUrl(urlLike) {
    var urlObj = url.parse(urlLike);
    if (typeof urlObj.host === 'string') {
        return 'absolute';
    }
    else if (typeof urlObj.pathname === 'string') {
        if (/^\//.test(urlObj.pathname)) {
            return 'root-relative';
        }
        else {
            return 'relative';
        }
    }
    else {
        return 'unknown';
    }
}
exports.classifyUrl = classifyUrl;
/**
 * It is mainly used to normalize the following last case.
 *
 *   url="https://foo.com/bar"  -> pathname="/bar"
 *   url="https://foo.com/bar/" -> pathname="/bar/"
 *   url="https://foo.com/"     -> pathname="/"
 *   url="https://foo.com"      -> pathname="/" (What's!?)
 */
function getPathnameWithoutTailingSlash(absoluteUrl) {
    var urlObj = url.parse(absoluteUrl);
    if (typeof urlObj.pathname === 'string') {
        return urlObj.pathname.replace(/\/$/, '');
    }
    throw new Error('An invalid url passed');
}
exports.getPathnameWithoutTailingSlash = getPathnameWithoutTailingSlash;
/**
 * @param path A relative url (e.g. "foo/bar", "./foo/bar") or
 *               slash-started relative url (e.g. "/foo/bar")
 */
function removeTailingResourceNameFromPath(path) {
    return path.replace(/(\/)?[^/]+$/, '$1');
}
exports.removeTailingResourceNameFromPath = removeTailingResourceNameFromPath;
function permalinksToRelativeUrl(fromPermalink, toPermalink) {
    // NOTICE: Originally `path.relative()` should not be used for URLs.
    //         In this time, there is probably no inconsistency, so there is no problem.
    var relativeDir = path.relative(path.dirname('.' + fromPermalink), path.dirname('.' + toPermalink));
    return path.join(relativeDir, path.basename(toPermalink));
}
exports.permalinksToRelativeUrl = permalinksToRelativeUrl;
function generateBlogPaths(blogRoot, relativePublicationDirPath) {
    var sourceRoot = path.join(blogRoot, RELATIVE_SOURCE_DIR_PATH);
    var publicationRoot = path.join(blogRoot, relativePublicationDirPath);
    var sourceArticlesRoot = path.join(sourceRoot, exports.RELATIVE_ARTICLES_DIR_PATH);
    var sourceExternalResourcesRoot = path.join(sourceRoot, exports.RELATIVE_EXTERNAL_RESOURCES_DIR_PATH);
    var sourceExternalResourcesDirectPlacementRoot = path.join(sourceExternalResourcesRoot, RELATIVE_EXTERNAL_RESOURCES_DIRECT_PLACEMENT_DIR_PATH);
    var publicationArticlesRoot = path.join(publicationRoot, exports.RELATIVE_ARTICLES_DIR_PATH);
    var publicationExternalResourcesRoot = path.join(publicationRoot, exports.RELATIVE_EXTERNAL_RESOURCES_DIR_PATH);
    var publicationExternalResourcesDirectPlacementRoot = path.join(publicationExternalResourcesRoot, RELATIVE_EXTERNAL_RESOURCES_DIRECT_PLACEMENT_DIR_PATH);
    return {
        sourceRoot: sourceRoot,
        publicationRoot: publicationRoot,
        sourceArticlesRoot: sourceArticlesRoot,
        sourceExternalResourcesRoot: sourceExternalResourcesRoot,
        sourceExternalResourcesDirectPlacementRoot: sourceExternalResourcesDirectPlacementRoot,
        publicationArticlesRoot: publicationArticlesRoot,
        publicationExternalResourcesRoot: publicationExternalResourcesRoot,
        publicationExternalResourcesDirectPlacementRoot: publicationExternalResourcesDirectPlacementRoot,
    };
}
exports.generateBlogPaths = generateBlogPaths;
function generateDateTimeString(date, timeZone, options) {
    if (options === void 0) { options = {}; }
    var formatString = 'YYYY-MM-DD HH:mm:ss';
    if (options.timeZoneSuffix === true) {
        formatString += 'ZZ';
    }
    return date_fns_timezone_1.formatToTimeZone(date, formatString, { timeZone: timeZone });
}
exports.generateDateTimeString = generateDateTimeString;
function generateTodayDateString(date, timeZone) {
    return date_fns_timezone_1.formatToTimeZone(date, 'YYYYMMDD', { timeZone: timeZone });
}
exports.generateTodayDateString = generateTodayDateString;
function extractPageTitle(node) {
    var fragments = [];
    unistUtilVisit(node, function (heading1Node) {
        if (heading1Node.type === 'heading' && heading1Node.depth === 1) {
            unistUtilVisit(heading1Node, function (n) {
                var trimmed = (n.value || '').trim();
                if (trimmed) {
                    fragments.push(trimmed);
                }
            });
            return unistUtilVisit.EXIT;
        }
    });
    return fragments.join(' ');
}
exports.extractPageTitle = extractPageTitle;
